Crate cellular_raza_core_proc_macro

source ·
This crate provides powerful macros to derive traits from the core crate. It also provides macros to automatically construct AuxStorage structs used to store intermediate data for running update steps and Communicator struct to send messages between threads running the simulation.

All macros are documented in the core crate unless their functionality can be displayed without any additional dependencies.

Modules

Macros

Derive Macros