Crate cellular_raza_core_proc_macro
source ยทExpand description
This crate provides powerful macros to derive traits from the core crate. It also provides macros to automatically construct AuxStorage structs used to store intermediate data for running update steps and Communicator struct to send messages between threads running the simulation.
All macros are documented in the core crate unless their functionality can be displayed without any additional dependencies.
Modules
- aux_storage ๐The main two macros are derive_aux_storage and construct_aux_storage which allow to derive individual aspects of the the update traits in
cellular_raza_core - communicator ๐
- from_map ๐
- run_sim ๐
- simulation_aspects ๐
- testing ๐
Macros
- Inserts as many blanks as generics were used to create the communicator struct by build_communicator!.
- Prepares communicator and auxiliary storage types with build_communicator! and build_aux_storage!.
- Construct, test and run a full simulation.
- Run a particularly structured test multiple times for combinations of aspects
- Checks if defined types and concepts are compatible before actually executing the simulation.